@@ -99,7 +99,8 @@ def create_testet_file(projectName, pipelineType):
     with open(os.path.join(__location__, 'cli/tester/' + pipelineType + '_template.py'), 'r') as file:
         data = file.read()
         projectNameNoUnderscore = ''.join(elem.capitalize() for elem in projectName.split('_'))
-        className = projectNameNoUnderscore + pipelineType.capitalize()
+        pipelineTypeNoUnderscore = ''.join(elem.capitalize() for elem in pipelineType.split('_'))
+        className = projectNameNoUnderscore + pipelineTypeNoUnderscore
         classNameFotBaseObject = projectNameNoUnderscore + '_' + pipelineType
         data = data.replace('generatedClassName', classNameFotBaseObject)
         data = data.replace('generatedClass',className)
