@@ -1,6 +1,6 @@
 from typing import Dict, Any, List
-from lib import PreprocessorBase, ZIDSConfig, SharedArtifacts
-from lib.base_classes import PredictableBase
+from dsFramework import PreprocessorBase, ZIDSConfig, SharedArtifacts
+from dsFramework.base_classes import PredictableBase
 
 class generatedClass(PreprocessorBase):
     def __init__(self, config: ZIDSConfig, shared_artifacts: SharedArtifacts, name: str = 'generatedClassName',
